


## TODO:

### v0.1
[ ] Comment and document everything
[ ] Prepare stub file
[ ] Implement as many dunder methods as possible
[ ] Implement `chroot` to select a subtree


### v0.2
[ ] Translate some methods into iterators
[ ] Refactor the code